@@ -1,8 +1,11 @@
 package HTML::Tag::SPAN;
 
+use strict;
+use warnings;
+
 use base 'HTML::Tag';
 
-$HTML::Tag::SPAN::VERSION = '0.02';
+$HTML::Tag::SPAN::VERSION = '0.03';
 
 use Class::Builder (
 	'-methods' 	=> { constructor => 'create' },
